@@ -1,6 +1,6 @@
-/* Copyright (c) 2015-2017, 2019-2020 The Khronos Group Inc.
- * Copyright (c) 2015-2017, 2019-2020 Valve Corporation
- * Copyright (c) 2015-2017, 2019-2020 LunarG, Inc.
+/* Copyright (c) 2015-2017, 2019-2021 The Khronos Group Inc.
+ * Copyright (c) 2015-2017, 2019-2021 Valve Corporation
+ * Copyright (c) 2015-2017, 2019-2021 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -27,7 +27,7 @@
 #include <stdbool.h>
 #include <string>
 #include <vector>
-#include <set>
+#include <iomanip>
 #include "cast_utils.h"
 #include "vk_format_utils.h"
 #include "vk_layer_logging.h"
@@ -42,6 +42,27 @@
 #define STRINGIFY_HELPER(s) #s
 
 #ifdef __cplusplus
+static inline VkExtent3D CastTo3D(const VkExtent2D &d2) {
+    VkExtent3D d3 = {d2.width, d2.height, 1};
+    return d3;
+}
+
+static inline VkOffset3D CastTo3D(const VkOffset2D &d2) {
+    VkOffset3D d3 = {d2.x, d2.y, 0};
+    return d3;
+}
+
+// Convert integer API version to a string
+static inline std::string StringAPIVersion(uint32_t version) {
+    std::stringstream version_name;
+    uint32_t major = VK_VERSION_MAJOR(version);
+    uint32_t minor = VK_VERSION_MINOR(version);
+    uint32_t patch = VK_VERSION_PATCH(version);
+    version_name << major << "." << minor << "." << patch << " (0x" << std::setfill('0') << std::setw(8) << std::hex << version
+                 << ")";
+    return version_name.str();
+}
+
 // Traits objects to allow string_join to operate on collections of const char *
 template <typename String>
 struct StringJoinSizeTrait {
@@ -166,6 +187,17 @@ static inline uint32_t SampleCountSize(VkSampleCountFlagBits sample_count) {
     return size;
 }
 
+static inline bool IsIdentitySwizzle(VkComponentMapping components) {
+    // clang-format off
+    return (
+        ((components.r == VK_COMPONENT_SWIZZLE_IDENTITY) || (components.r == VK_COMPONENT_SWIZZLE_R)) &&
+        ((components.g == VK_COMPONENT_SWIZZLE_IDENTITY) || (components.g == VK_COMPONENT_SWIZZLE_G)) &&
+        ((components.b == VK_COMPONENT_SWIZZLE_IDENTITY) || (components.b == VK_COMPONENT_SWIZZLE_B)) &&
+        ((components.a == VK_COMPONENT_SWIZZLE_IDENTITY) || (components.a == VK_COMPONENT_SWIZZLE_A))
+    );
+    // clang-format on
+}
+
 extern "C" {
 #endif
 
@@ -203,14 +235,16 @@ static inline int u_ffs(int val) {
 }
 #endif
 
-// shared_mutex support added in MSVC 2015 update 2
-#if defined(_MSC_FULL_VER) && _MSC_FULL_VER >= 190023918 && NTDDI_VERSION > NTDDI_WIN10_RS2
+// Minimum Visual Studio 2015 Update 2, or libc++ with C++17
+#if defined(_MSC_FULL_VER) && _MSC_FULL_VER >= 190023918 && NTDDI_VERSION > NTDDI_WIN10_RS2 && \
+    (!defined(_LIBCPP_VERSION) || __cplusplus >= 201703)
 #include <shared_mutex>
 #endif
 
 class ReadWriteLock {
   private:
-#if defined(_MSC_FULL_VER) && _MSC_FULL_VER >= 190023918 && NTDDI_VERSION > NTDDI_WIN10_RS2
+#if defined(_MSC_FULL_VER) && _MSC_FULL_VER >= 190023918 && NTDDI_VERSION > NTDDI_WIN10_RS2 && \
+    (!defined(_LIBCPP_VERSION) || __cplusplus >= 201703)
     typedef std::shared_mutex lock_t;
 #else
     typedef std::mutex lock_t;
@@ -220,7 +254,8 @@ class ReadWriteLock {
     void lock() { m_lock.lock(); }
     bool try_lock() { return m_lock.try_lock(); }
     void unlock() { m_lock.unlock(); }
-#if defined(_MSC_FULL_VER) && _MSC_FULL_VER >= 190023918 && NTDDI_VERSION > NTDDI_WIN10_RS2
+#if defined(_MSC_FULL_VER) && _MSC_FULL_VER >= 190023918 && NTDDI_VERSION > NTDDI_WIN10_RS2 && \
+    (!defined(_LIBCPP_VERSION) || __cplusplus >= 201703)
     void lock_shared() { m_lock.lock_shared(); }
     bool try_lock_shared() { return m_lock.try_lock_shared(); }
     void unlock_shared() { m_lock.unlock_shared(); }
@@ -233,7 +268,8 @@ class ReadWriteLock {
     lock_t m_lock;
 };
 
-#if defined(_MSC_FULL_VER) && _MSC_FULL_VER >= 190023918 && NTDDI_VERSION > NTDDI_WIN10_RS2
+#if defined(_MSC_FULL_VER) && _MSC_FULL_VER >= 190023918 && NTDDI_VERSION > NTDDI_WIN10_RS2 && \
+    (!defined(_LIBCPP_VERSION) || __cplusplus >= 201703)
 typedef std::shared_lock<ReadWriteLock> read_lock_guard_t;
 typedef std::unique_lock<ReadWriteLock> write_lock_guard_t;
 #else
@@ -265,7 +301,7 @@ typedef std::unique_lock<ReadWriteLock> write_lock_guard_t;
 //
 // snapshot: Return an array of elements (key, value pairs) that satisfy an optional
 // predicate. This can be used as a substitute for iterators in exceptional cases.
-template <typename Key, typename T, int BUCKETSLOG2 = 2, typename Hash = std::hash<Key>>
+template <typename Key, typename T, int BUCKETSLOG2 = 2, typename Hash = layer_data::hash<Key>>
 class vl_concurrent_unordered_map {
   public:
     void insert_or_assign(const Key &key, const T &value) {
@@ -277,7 +313,7 @@ class vl_concurrent_unordered_map {
     bool insert(const Key &key, const T &value) {
         uint32_t h = ConcurrentMapHashObject(key);
         write_lock_guard_t lock(locks[h].lock);
-        auto ret = maps[h].insert(typename std::unordered_map<Key, T>::value_type(key, value));
+        auto ret = maps[h].emplace(key, value);
         return ret.second;
     }
 
@@ -355,9 +391,9 @@ class vl_concurrent_unordered_map {
         std::vector<std::pair<const Key, T>> ret;
         for (int h = 0; h < BUCKETS; ++h) {
             read_lock_guard_t lock(locks[h].lock);
-            for (auto j : maps[h]) {
+            for (const auto &j : maps[h]) {
                 if (!f || f(j.second)) {
-                    ret.push_back(j);
+                    ret.emplace_back(j.first, j.second);
                 }
             }
         }
@@ -367,7 +403,7 @@ class vl_concurrent_unordered_map {
   private:
     static const int BUCKETS = (1 << BUCKETSLOG2);
 
-    std::unordered_map<Key, T, Hash> maps[BUCKETS];
+    layer_data::unordered_map<Key, T, Hash> maps[BUCKETS];
     struct {
         mutable ReadWriteLock lock;
         // Put each lock on its own cache line to avoid false cache line sharing.
